.. _gallery-labels:

Labels
===========

This gallery contains examples of how to add labels to plots using the ``mplhep`` package.

The following plots show the same data with different label positions, using the experiment specific
label methods such as :py:func:`~mplhep.cms.label()` and the position argument ``loc`` to place the label.


Position 0
-------------------

.. image:: ../../_static/_generated/ATLAS/fill/pos0.png
   :width: 45%

.. image:: ../../_static/_generated/ATLASAlt/fill/pos0.png
   :width: 45%

.. image:: ../../_static/_generated/LHCb1/fill/pos0.png
   :width: 45%

.. image:: ../../_static/_generated/LHCb2/fill/pos0.png
   :width: 45%

.. image:: ../../_static/_generated/CMS/fill/pos0.png
   :width: 45%

Position 1
-------------------

.. image:: ../../_static/_generated/ATLAS/fill/pos1.png
   :width: 45%

.. image:: ../../_static/_generated/ATLASAlt/fill/pos1.png
   :width: 45%

.. image:: ../../_static/_generated/LHCb1/fill/pos1.png
   :width: 45%

.. image:: ../../_static/_generated/LHCb2/fill/pos1.png
   :width: 45%

.. image:: ../../_static/_generated/CMS/fill/pos1.png
   :width: 45%

Position 2
-------------------

.. image:: ../../_static/_generated/ATLAS/fill/pos2.png
   :width: 45%

.. image:: ../../_static/_generated/ATLASAlt/fill/pos2.png
   :width: 45%

.. image:: ../../_static/_generated/LHCb1/fill/pos2.png
   :width: 45%

.. image:: ../../_static/_generated/LHCb2/fill/pos2.png
   :width: 45%

.. image:: ../../_static/_generated/CMS/fill/pos2.png
   :width: 45%

Position 3
-------------------

.. image:: ../../_static/_generated/ATLAS/fill/pos3.png
   :width: 45%

.. image:: ../../_static/_generated/ATLASAlt/fill/pos3.png
   :width: 45%

.. image:: ../../_static/_generated/LHCb1/fill/pos3.png
   :width: 45%

.. image:: ../../_static/_generated/LHCb2/fill/pos3.png
   :width: 45%

.. image:: ../../_static/_generated/CMS/fill/pos3.png
   :width: 45%

Position 4
-------------------

.. image:: ../../_static/_generated/ATLAS/fill/pos4.png
   :width: 45%

.. image:: ../../_static/_generated/ATLASAlt/fill/pos4.png
   :width: 45%

.. image:: ../../_static/_generated/LHCb1/fill/pos4.png
   :width: 45%

.. image:: ../../_static/_generated/LHCb2/fill/pos4.png
   :width: 45%

.. image:: ../../_static/_generated/CMS/fill/pos4.png
   :width: 45%
